# PyDrop

## 안드로이드도 에어드랍이 쓰고싶어!

핸드폰에서 노트북으로 영상/이미지 등의 파일을 옮기는것이 귀찮을때.. Near By Share나 AirDrop이 부러울때..
난 핫스팟으로 파이드랍한다!

## 사용방법 (macOS 기준)

### 환경 셋팅

Python 3.12버전을 사용합니다.

#### Poetry 설치
Poetry가 다운로드되어있지 않은 경우, 터미널 창에 다음 코드를 입력합니다.
```
pip install poetry
```

#### 개발 환경 설정
터미널창에 다음 코드를 입력합니다.
```
poetry install
```

#### 서버 실행 방법
터미널창에 다음 코드를 입력합니다.
```
make run
```

### 사용 방법

0. /PyDrop/env.py에서 저장 위치를 결정합니다. (기본적으로는 루트폴더의 /storage에 저장됩니다.)
1. 핸드폰으로 핫스팟을 켠다
2. 맥북으로 해당 와이파이에 연결한다 **(같은 인터넷에 연결 되어있다면, 핫스팟이 아니더라도 가능합니다!)**
3. 서버를 실행합니다.
4. 와이파이 - 와이파이 설정 - IP주소를 확인한다. (ex: 192.168.0.1)
5. 핸드폰으로 http://해당 주소:8001/docs에 접속한다 (ex: http://192.168.0.1:8001)
6. /upload를 try it out 한후, 파일을 고르고 Execute한다.
7. 터미널 창에 exit를 입력하여 서버를 끌 수 있습니다.